"""Integration tests for Budgets API."""
import unittest
from datetime import date

import organizze_api
from organizze_api.rest import ApiException

from .base_test import BaseIntegrationTest


class TestBudgetsApiIntegration(BaseIntegrationTest):
    """Integration tests for Budgets API endpoints."""

    def setUp(self) -> None:
        """Set up test case."""
        super().setUp()
        self.budgets_api = organizze_api.BudgetsApi(self.api_client)

    def test_list_current_month_budgets(self) -> None:
        """Test listing current month budgets."""
        try:
            budgets = self.budgets_api.list_current_month_budgets()
            self.assertIsNotNone(budgets, "Budgets list should not be None")
            self.assertIsInstance(budgets, list, "Budgets should be a list")
            print(f"✓ Successfully retrieved {len(budgets)} budget(s) for current month")

            if len(budgets) > 0:
                budget = budgets[0]
                self.assertIsNotNone(budget.category_id, "Budget should have a category ID")
                print(f"  Sample budget - Category ID: {budget.category_id}, Amount: {budget.amount_in_cents}")
        except ApiException as e:
            self.fail(f"Failed to list current month budgets: {e}")

    def test_list_monthly_budgets(self) -> None:
        """Test listing budgets for a specific month."""
        try:
            today = date.today()
            year = today.year
            month = today.month

            budgets = self.budgets_api.list_monthly_budgets(year, month)
            self.assertIsNotNone(budgets, "Budgets list should not be None")
            self.assertIsInstance(budgets, list, "Budgets should be a list")
            print(f"✓ Successfully retrieved {len(budgets)} budget(s) for {year}/{month:02d}")
        except ApiException as e:
            self.fail(f"Failed to list monthly budgets: {e}")

    def test_list_annual_budgets(self) -> None:
        """Test listing annual budgets."""
        try:
            year = date.today().year
            budgets = self.budgets_api.list_annual_budgets(year)
            self.assertIsNotNone(budgets, "Budgets list should not be None")
            self.assertIsInstance(budgets, list, "Budgets should be a list")
            print(f"✓ Successfully retrieved {len(budgets)} budget(s) for year {year}")
        except ApiException as e:
            self.fail(f"Failed to list annual budgets: {e}")


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Category(BaseModel):
    """
    Category
    """ # noqa: E501
    id: Annotated[int, Field(le=2147483647, strict=True, ge=1)]
    name: StrictStr
    color: Annotated[str, Field(min_length=6, strict=True, max_length=6)]
    parent_id: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]]
    group_id: StrictStr
    fixed: StrictBool
    essential: StrictBool
    default: StrictBool
    uuid: StrictStr
    kind: StrictStr
    archived: StrictBool
    __properties: ClassVar[List[str]] = ["id", "name", "color", "parent_id", "group_id", "fixed", "essential", "default", "uuid", "kind", "archived"]

    @field_validator('color')
    def color_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-fA-F0-9]{6}$", value):
            raise ValueError(r"must validate the regular expression /^[a-fA-F0-9]{6}$/")
        return value

    @field_validator('kind')
    def kind_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['expenses', 'earnings', 'none']):
            raise ValueError("must be one of enum values ('expenses', 'earnings', 'none')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Category from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if parent_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_id is None and "parent_id" in self.model_fields_set:
            _dict['parent_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Category from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "color": obj.get("color"),
            "parent_id": obj.get("parent_id"),
            "group_id": obj.get("group_id"),
            "fixed": obj.get("fixed"),
            "essential": obj.get("essential"),
            "default": obj.get("default"),
            "uuid": obj.get("uuid"),
            "kind": obj.get("kind"),
            "archived": obj.get("archived")
        })
        return _obj





"""Integration tests for Bank Accounts API."""
import unittest

import organizze_api
from organizze_api.rest import ApiException

from .base_test import BaseIntegrationTest


class TestBankAccountsApiIntegration(BaseIntegrationTest):
    """Integration tests for Bank Accounts API endpoints."""

    def setUp(self) -> None:
        """Set up test case."""
        super().setUp()
        self.bank_accounts_api = organizze_api.BankAccountsApi(self.api_client)

    def test_list_bank_accounts(self) -> None:
        """Test listing bank accounts."""
        try:
            accounts = self.bank_accounts_api.list_bank_accounts()
            self.assertIsNotNone(accounts, "Bank accounts list should not be None")
            self.assertIsInstance(accounts, list, "Bank accounts should be a list")

            if len(accounts) > 0:
                account = accounts[0]
                self.assertIsNotNone(account.id, "Account should have an ID")
                self.assertIsNotNone(account.name, "Account should have a name")
                print(f"✓ Successfully retrieved {len(accounts)} bank account(s)")
                print(f"  Sample account: {account.name}")
        except ApiException as e:
            self.fail(f"Failed to list bank accounts: {e}")

    def test_read_bank_account(self) -> None:
        """Test reading a specific bank account."""
        try:
            # First get the list of accounts to get a valid account ID
            accounts = self.bank_accounts_api.list_bank_accounts()
            self.assertIsNotNone(accounts, "Bank accounts list should not be None")

            if len(accounts) == 0:
                self.skipTest("No bank accounts available to test reading")
                return

            # Read the first account
            account_id = accounts[0].id
            account = self.bank_accounts_api.read_bank_account(account_id)

            self.assertIsNotNone(account, "Account should not be None")
            self.assertEqual(account.id, account_id, "Account ID should match")
            self.assertIsNotNone(account.name, "Account should have a name")
            print(f"✓ Successfully read bank account: {account.name}")
        except ApiException as e:
            self.fail(f"Failed to read bank account: {e}")

    def test_create_update_delete_bank_account(self) -> None:
        """Test creating, updating, and deleting a bank account (full lifecycle)."""
        created_account_id = None

        try:
            # Create a new bank account
            # Note: type field should be omitted or set to valid values like "other" or "bank"
            new_account = organizze_api.BankAccountInput(
                name="Test Account SDK",
                description="Created by SDK integration tests",
                type="other"  # Valid values: "other", "bank", etc.
            )

            created_account = self.bank_accounts_api.create_bank_account(new_account)
            self.assertIsNotNone(created_account, "Created account should not be None")
            self.assertIsNotNone(created_account.id, "Created account should have an ID")
            created_account_id = created_account.id
            print(f"✓ Successfully created bank account with ID: {created_account_id}")

            # Update the account
            update_data = organizze_api.BankAccountInput(
                name="Test Account SDK Updated",
                description="Updated by SDK integration tests",
                type="other"
            )
            updated_account = self.bank_accounts_api.update_bank_account(
                created_account_id,
                update_data
            )
            # Some API operations may return None on successful update
            if updated_account is not None:
                self.assertEqual(
                    updated_account.name,
                    "Test Account SDK Updated",
                    "Account name should be updated"
                )
                print(f"✓ Successfully updated bank account: {updated_account.name}")
            else:
                print(f"✓ Successfully updated bank account with ID: {created_account_id}")

            # Delete the account
            self.bank_accounts_api.delete_bank_account(created_account_id)
            print(f"✓ Successfully deleted bank account with ID: {created_account_id}")
            created_account_id = None  # Mark as deleted

        except ApiException as e:
            # Clean up if test fails
            if created_account_id:
                try:
                    self.bank_accounts_api.delete_bank_account(created_account_id)
                    print(f"  Cleaned up bank account with ID: {created_account_id}")
                except ApiException:
                    pass
            self.fail(f"Bank account lifecycle test failed: {e}")


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from organizze_api.models.transaction import Transaction
from organizze_api.models.tag import Tag

class TestTransaction(unittest.TestCase):
    """Transaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Transaction:
        """Test Transaction
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        if include_optional:
            return Transaction(
                id = 1,
                description = 'Test transaction',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                paid = True,
                amount_cents = -2147483647,
                total_installments = 1,
                installment = 1,
                recurring = True,
                account_id = 1,
                account_type = 'Account',
                category_id = 1,
                notes = 'Test notes',
                attachments_count = 0,
                credit_card_id = 1,
                credit_card_invoice_id = 1,
                paid_credit_card_id = 1,
                paid_credit_card_invoice_id = 1,
                oposite_transaction_id = 1,
                oposite_account_id = 1,
                created_at = datetime.datetime.now(),
                updated_at = datetime.datetime.now(),
                tags = [
                    Tag(name='expenses'),
                    Tag(name='groceries')
                ],
                attachments = []
            )
        else:
            return Transaction()

    def testTransaction(self):
        """Test Transaction"""
        self.make_instance(include_optional=False)
        self.make_instance(include_optional=True)

    def testTransactionWithTags(self):
        """Test Transaction with Tag objects"""
        tag1 = Tag(name="expenses")
        tag2 = Tag(name="groceries")

        transaction = Transaction(
            description="Supermarket purchase",
            tags=[tag1, tag2]
        )

        self.assertIsNotNone(transaction.tags)
        self.assertEqual(len(transaction.tags), 2)
        self.assertEqual(transaction.tags[0].name, "expenses")
        self.assertEqual(transaction.tags[1].name, "groceries")

    def testTransactionFromDictWithTags(self):
        """Test Transaction deserialization with tags as objects (API format)"""
        transaction_dict = {
            "id": 2477483422,
            "description": "Despesa fixa",
            "date": "2015-09-16",
            "paid": True,
            "amount_cents": 0,
            "total_installments": 1,
            "installment": 1,
            "recurring": False,
            "account_id": 6632818,
            "category_id": 120321159,
            "notes": "Pagamento via boleto",
            "attachments_count": 0,
            "tags": [
                {"name": "expenses"},
                {"name": "recurring"}
            ],
            "attachments": []
        }

        transaction = Transaction.from_dict(transaction_dict)

        self.assertIsNotNone(transaction)
        self.assertIsNotNone(transaction.tags)
        self.assertEqual(len(transaction.tags), 2)
        self.assertIsInstance(transaction.tags[0], Tag)
        self.assertEqual(transaction.tags[0].name, "expenses")
        self.assertEqual(transaction.tags[1].name, "recurring")

    def testTransactionToDict(self):
        """Test Transaction serialization with tags"""
        tag1 = Tag(name="expenses")
        tag2 = Tag(name="groceries")

        transaction = Transaction(
            description="Test transaction",
            tags=[tag1, tag2]
        )

        transaction_dict = transaction.to_dict()

        self.assertIn("tags", transaction_dict)
        self.assertEqual(len(transaction_dict["tags"]), 2)
        self.assertEqual(transaction_dict["tags"][0]["name"], "expenses")
        self.assertEqual(transaction_dict["tags"][1]["name"], "groceries")

if __name__ == '__main__':
    unittest.main()



"""Integration tests for Categories API."""
import unittest

import organizze_api
from organizze_api.rest import ApiException

from .base_test import BaseIntegrationTest


class TestCategoriesApiIntegration(BaseIntegrationTest):
    """Integration tests for Categories API endpoints."""

    def setUp(self) -> None:
        """Set up test case."""
        super().setUp()
        self.categories_api = organizze_api.CategoriesApi(self.api_client)

    def test_list_categories(self) -> None:
        """Test listing categories."""
        try:
            categories = self.categories_api.list_categories()
            self.assertIsNotNone(categories, "Categories list should not be None")
            self.assertIsInstance(categories, list, "Categories should be a list")

            if len(categories) > 0:
                category = categories[0]
                self.assertIsNotNone(category.id, "Category should have an ID")
                self.assertIsNotNone(category.name, "Category should have a name")
                print(f"✓ Successfully retrieved {len(categories)} category(ies)")
                print(f"  Sample category: {category.name}")
        except ApiException as e:
            self.fail(f"Failed to list categories: {e}")

    def test_read_category(self) -> None:
        """Test reading a specific category."""
        try:
            # First get the list of categories to get a valid category ID
            categories = self.categories_api.list_categories()
            self.assertIsNotNone(categories, "Categories list should not be None")

            if len(categories) == 0:
                self.skipTest("No categories available to test reading")
                return

            # Read the first category
            category_id = categories[0].id
            category = self.categories_api.read_category(category_id)

            self.assertIsNotNone(category, "Category should not be None")
            self.assertEqual(category.id, category_id, "Category ID should match")
            self.assertIsNotNone(category.name, "Category should have a name")
            print(f"✓ Successfully read category: {category.name}")
        except ApiException as e:
            self.fail(f"Failed to read category: {e}")

    def test_create_update_delete_category(self) -> None:
        """Test creating, updating, and deleting a category (full lifecycle)."""
        created_category_id = None

        try:
            # Create a new category
            # Color format: lowercase hex without # (e.g., "ff5733")
            new_category = organizze_api.CategoryInput(
                name="Test Category SDK",
                color="ff5733"
            )

            created_category = self.categories_api.create_category(new_category)
            self.assertIsNotNone(created_category, "Created category should not be None")
            self.assertIsNotNone(created_category.id, "Created category should have an ID")
            created_category_id = created_category.id
            print(f"✓ Successfully created category with ID: {created_category_id}")

            # Update the category
            update_data = organizze_api.CategoryInput(
                name="Test Category SDK Updated",
                color="ffd5ff"
            )
            updated_category = self.categories_api.update_category(
                created_category_id,
                update_data
            )
            # Some API operations may return None on successful update
            if updated_category is not None:
                self.assertEqual(
                    updated_category.name,
                    "Test Category SDK Updated",
                    "Category name should be updated"
                )
                print(f"✓ Successfully updated category: {updated_category.name}")
            else:
                print(f"✓ Successfully updated category with ID: {created_category_id}")

            # Delete the category
            self.categories_api.delete_category(created_category_id)
            print(f"✓ Successfully deleted category with ID: {created_category_id}")
            created_category_id = None  # Mark as deleted

        except ApiException as e:
            # Clean up if test fails
            if created_category_id:
                try:
                    self.categories_api.delete_category(created_category_id)
                    print(f"  Cleaned up category with ID: {created_category_id}")
                except ApiException:
                    pass
            self.fail(f"Category lifecycle test failed: {e}")


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.credit_card_invoice_full import CreditCardInvoiceFull

class TestCreditCardInvoiceFull(unittest.TestCase):
    """CreditCardInvoiceFull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreditCardInvoiceFull:
        """Test CreditCardInvoiceFull
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreditCardInvoiceFull`
        """
        model = CreditCardInvoiceFull()
        if include_optional:
            return CreditCardInvoiceFull(
                id = 1,
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                starting_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                closing_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                amount_cents = 0,
                payment_amount_cents = 0,
                balance_cents = 0,
                previous_balance_cents = 0,
                credit_card_id = 1,
                transactions = [
                    {"id":2477483422,"description":"Despesa fixa","date":"2015-09-16","paid":true,"amount_cents":0,"total_installments":1,"installment":1,"recurring":false,"account_id":6632818,"category_id":120321159,"notes":"Pagamento via boleto","attachments_count":0,"credit_card_id":null,"credit_card_invoice_id":null,"paid_credit_card_id":null,"paid_credit_card_invoice_id":null,"oposite_transaction_id":null,"oposite_account_id":null,"created_at":"2023-04-08T12:32:16-03:00","updated_at":"2023-04-08T12:32:16-03:00","tags":[],"attachments":[]}
                    ],
                payments = [
                    {"id":2477483422,"description":"Despesa fixa","date":"2015-09-16","paid":true,"amount_cents":0,"total_installments":1,"installment":1,"recurring":false,"account_id":6632818,"category_id":120321159,"notes":"Pagamento via boleto","attachments_count":0,"credit_card_id":null,"credit_card_invoice_id":null,"paid_credit_card_id":null,"paid_credit_card_invoice_id":null,"oposite_transaction_id":null,"oposite_account_id":null,"created_at":"2023-04-08T12:32:16-03:00","updated_at":"2023-04-08T12:32:16-03:00","tags":[],"attachments":[]}
                    ]
            )
        else:
            return CreditCardInvoiceFull(
        )
        """

    def testCreditCardInvoiceFull(self):
        """Test CreditCardInvoiceFull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Organizze API

    Specification for the Organizze API described in [https://github.com/organizze/api-doc](https://github.com/organizze/api-doc)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from organizze_api.models.credit_card_input import CreditCardInput

class TestCreditCardInput(unittest.TestCase):
    """CreditCardInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreditCardInput:
        """Test CreditCardInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreditCardInput`
        """
        model = CreditCardInput()
        if include_optional:
            return CreditCardInput(
                name = '',
                description = '',
                card_network = '',
                closing_day = 1,
                due_day = 1,
                limit_cents = 0,
                archived = True,
                default = True,
                institution_id = ''
            )
        else:
            return CreditCardInput(
                name = '',
                closing_day = 1,
                due_day = 1,
        )
        """

    def testCreditCardInput(self):
        """Test CreditCardInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
